# Django settings for WebXiangpianbu project.

import os
SITE_ROOT = os.path.dirname(os.path.realpath(__file__))
BASE_DIR = SITE_ROOT

DEBUG = False
TEMPLATE_DEBUG = DEBUG

# Hosts/domain names that are valid for this site; required if DEBUG is False
# See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
ALLOWED_HOSTS = [
    'localhost',
    '127.0.0.1',
]

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = 'UTC'

LANGUAGES = (
    ('en', u'English'),
    ('pl', u'Polski'),
)
LANGUAGE_CODE = 'en-us'
LANGUAGE_COOKIE_NAME = 'lang'
DEFAULT_LANGUAGE = 1

# Directories where Django looks for translation files.
LOCALE_PATHS = (
    os.path.join(SITE_ROOT, '../locale'),
)

CACHES = {
    'default': {
#       'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
        'BACKEND': 'django.core.cache.backends.dummy.DummyCache',
        'LOCATION': '127.0.0.1:11211',
        'KEY_PREFIX': 'webxiang',
    },
}

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.
USE_L10N = False

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = True

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/var/www/example.com/static/"
STATIC_ROOT = os.path.abspath(os.path.join(SITE_ROOT, '../static'))

# URL prefix for static files.
# Example: "http://example.com/static/", "http://static.example.com/"
STATIC_URL = '/static/'

STATICFILES_STORAGE = 'pipeline.storage.PipelineCachedStorage'
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'pipeline.finders.CachedFileFinder',
    'pipeline.finders.PipelineFinder',
)
STATICFILES_DIRS = (
    os.path.join(SITE_ROOT, 'static'),
)

PIPELINE_DISABLE_WRAPPER = True
PIPELINE_JS_COMPRESSOR = None
PIPELINE_CSS_COMPRESSOR = None

PIPELINE_JS = {
    'gallery': {
        'source_filenames': (
            'js/gallery.js',
        ),
        'output_filename': 'js/gallery.js',
    },
}

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'r(nrah(*_7afg06%!)j^k*^(*i9i7(&+*q2*capg$$8hhpan(t'

MIDDLEWARE_CLASSES = (
    'django.middleware.cache.UpdateCacheMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.cache.FetchFromCacheMiddleware',
)

ROOT_URLCONF = 'webxiang.urls'

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = 'webxiang.wsgi.application'

TEMPLATE_DIRS = (
    os.path.join(SITE_ROOT, 'templates'),
)

INSTALLED_APPS = (
    'django.contrib.staticfiles',
    'pipeline',
    'webxiang',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}

#
# WebXiangpianbu specific settings.
#

SITE_URL = 'www.example.org/'

WEBXIANG_PHOTOS_URL = '/data/'

# Absolute path to the directory containing photo files (JPEGs).
WEBXIANG_PHOTOS_ROOT = '/home/user/photos/data/'

# Photos lazy loading (requires jQuery plugin)
WEBXIANG_PHOTOS_LAZY = False

ALBUM_DIR = os.path.join(SITE_ROOT, '../albums')
CACHE_DIR = os.path.join(SITE_ROOT, '../cached')

COPYRIGHT_OWNER = 'Your Name'

WXPB_SETTINGS = {
    'geo_map_plugin': 'leaflet',  # leaflet, mapbox, google
    'geo_leaflet_layers': {
        'OpenStreetMap': {'id': 'osm.mapnik', 'is_default': True},
        # 'Custom': {'id': 'MAPID', 'type': 'mapbox'}
    },
    #'mapbox_accessToken': '',
}
